@@ -114,14 +114,6 @@
         <translation>[tập_tin1, tập_tin2,...]</translation>
     </message>
 </context>
-<context>
-    <name>LxImage::ImageShackUpload</name>
-    <message>
-        <location filename="../upload/imageshackupload.cpp" line="50"/>
-        <source>unknown error response</source>
-        <translation>phản hồi không rõ lỗi</translation>
-    </message>
-</context>
 <context>
     <name>LxImage::ImgBBUpload</name>
     <message>
@@ -141,88 +133,88 @@
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="277"/>
+        <location filename="../mainwindow.cpp" line="278"/>
         <source>About</source>
         <translation>Về</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../mainwindow.cpp" line="280"/>
         <source>A simple and fast image viewer</source>
         <translation>Trình xem ảnh đơn giản và nhanh chóng</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="281"/>
+        <location filename="../mainwindow.cpp" line="282"/>
         <source>Copyright (C) </source>
         <translation>Bản quyền (C) </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="281"/>
+        <location filename="../mainwindow.cpp" line="282"/>
         <source>2013-2021</source>
         <translation>2013-2021</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="283"/>
+        <location filename="../mainwindow.cpp" line="284"/>
         <source>LXQt Project</source>
         <translation>Dự án LXQt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="285"/>
+        <location filename="../mainwindow.cpp" line="286"/>
         <source>Development: </source>
         <translation>Phát triển: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../mainwindow.cpp" line="288"/>
         <source>Author: </source>
         <translation>Tác giả: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="515"/>
+        <location filename="../mainwindow.cpp" line="516"/>
         <source>Open File</source>
         <translation>Mở Tập tin</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="516"/>
-        <location filename="../mainwindow.cpp" line="551"/>
+        <location filename="../mainwindow.cpp" line="517"/>
+        <location filename="../mainwindow.cpp" line="552"/>
         <source>Image files (%1)</source>
         <translation>Tập tin ảnh (%1)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="529"/>
+        <location filename="../mainwindow.cpp" line="530"/>
         <source>Open directory</source>
         <translation>Mở thư mục</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="550"/>
+        <location filename="../mainwindow.cpp" line="551"/>
         <source>Save File</source>
         <translation>Lưu Tập tin</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="839"/>
+        <location filename="../mainwindow.cpp" line="847"/>
         <source>[*]%1 (Loading...) - Image Viewer</source>
         <translation>[*]%1 (Đang tải...) - Trình xem Ảnh</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="853"/>
         <source>[*]%1 (Failed to Load) - Image Viewer</source>
         <translation>[*]%1 (Tải Thất bại) - Trình xem Ảnh</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="851"/>
+        <location filename="../mainwindow.cpp" line="859"/>
         <source>[*]%1 (%2x%3) - Image Viewer</source>
         <translation>[*]%1 (%2x%3) - Trình xem Ảnh</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="897"/>
+        <location filename="../mainwindow.cpp" line="905"/>
         <source>[*]Image Viewer</source>
         <translation>[*]Trình xem Ảnh</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1294"/>
+        <location filename="../mainwindow.cpp" line="1302"/>
         <source>Thumbnails</source>
         <translation>Hình thu nhỏ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1389"/>
+        <location filename="../mainwindow.cpp" line="1397"/>
         <source>EXIF Data</source>
         <translation>Dữ liệu EXIF</translation>
     </message>
@@ -232,7 +224,7 @@
     <message>
         <location filename="../mrumenu.cpp" line="49"/>
         <source>&amp;Clear</source>
-        <translation>&amp;Xóa</translation>
+        <translation>Xóa (&amp;C)</translation>
     </message>
 </context>
 <context>
@@ -245,27 +237,27 @@ in the editing mode.</source>
 trong chế độ chỉnh sửa.</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="206"/>
+        <location filename="../preferencesdialog.cpp" line="213"/>
         <source>Bottom</source>
         <translation>Bên dưới</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="207"/>
+        <location filename="../preferencesdialog.cpp" line="214"/>
         <source>Top</source>
         <translation>Bên trên</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="208"/>
+        <location filename="../preferencesdialog.cpp" line="215"/>
         <source>Left</source>
         <translation>Bên trái</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="334"/>
+        <location filename="../preferencesdialog.cpp" line="341"/>
         <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
         <translation>&lt;b&gt;Cảnh báo: Lối tắt thiếu rõ ràng được phát hiện!&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.cpp" line="351"/>
+        <location filename="../preferencesdialog.cpp" line="358"/>
         <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
         <translation>&lt;b&gt;Lối tắt thiếu rõ ràng không được chấp nhận.&lt;/b&gt;</translation>
     </message>
@@ -294,37 +286,32 @@ trong chế độ chỉnh sửa.</translation>
 <context>
     <name>LxImage::UploadDialog</name>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="52"/>
+        <location filename="../upload/uploaddialog.cpp" line="50"/>
         <source>Imgur</source>
         <translation>Imgur</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="53"/>
+        <location filename="../upload/uploaddialog.cpp" line="51"/>
         <source>ImgBB</source>
         <translation>ImgBB</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="54"/>
-        <source>ImageShack</source>
-        <translation type="unfinished">ImageShack</translation>
-    </message>
-    <message>
-        <location filename="../upload/uploaddialog.cpp" line="137"/>
+        <location filename="../upload/uploaddialog.cpp" line="134"/>
         <source>Start</source>
         <translation>Bắt đầu</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="140"/>
+        <location filename="../upload/uploaddialog.cpp" line="137"/>
         <source>Stop</source>
         <translation>Ngừng</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="143"/>
+        <location filename="../upload/uploaddialog.cpp" line="140"/>
         <source>Close</source>
         <translation>Đóng</translation>
     </message>
     <message>
-        <location filename="../upload/uploaddialog.cpp" line="150"/>
+        <location filename="../upload/uploaddialog.cpp" line="147"/>
         <source>Error</source>
         <translation>Lỗi</translation>
     </message>
@@ -339,12 +326,12 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="72"/>
         <source>&amp;Recently Opened Files</source>
-        <translation>Tập tin được mở gần đây</translation>
+        <translation>Tập tin được mở gần đây (&amp;R)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="224"/>
         <source>&amp;About</source>
-        <translation>Về</translation>
+        <translation>Thông tin (&amp;A)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="204"/>
@@ -355,22 +342,22 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="67"/>
         <source>Open &amp;With...</source>
-        <translation>Mở bằng...</translation>
+        <translation>Mở bằng (&amp;W)...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="117"/>
         <source>Sorting</source>
-        <translation type="unfinished"></translation>
+        <translation>Sắp xếp</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="229"/>
         <source>Hidden &amp;Shortcuts</source>
-        <translation>Lối tắt ẩn</translation>
+        <translation>Lối tắt ẩn (&amp;S)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="238"/>
         <source>&amp;Open…</source>
-        <translation>Mở…</translation>
+        <translation>Mở (&amp;O)…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="241"/>
@@ -380,7 +367,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="250"/>
         <source>&amp;Reload File</source>
-        <translation>Mở lại tập tin</translation>
+        <translation>Mở lại Tập tin (&amp;R)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="253"/>
@@ -390,7 +377,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="262"/>
         <source>&amp;Save</source>
-        <translation>Lưu lại</translation>
+        <translation>Lưu lại (&amp;S)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="265"/>
@@ -400,7 +387,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="274"/>
         <source>Save &amp;As</source>
-        <translation>Lưu nơi khác</translation>
+        <translation>Lưu nơi khác (&amp;A)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="277"/>
@@ -410,7 +397,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="286"/>
         <source>&amp;Close</source>
-        <translation>Đóng</translation>
+        <translation>Đóng (&amp;C)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="289"/>
@@ -420,7 +407,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="298"/>
         <source>Zoom &amp;In</source>
-        <translation>Thu nhỏ</translation>
+        <translation>Phóng to (&amp;I)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="301"/>
@@ -430,7 +417,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="310"/>
         <source>Zoom &amp;Out</source>
-        <translation>Phóng to</translation>
+        <translation>Thu nhỏ (&amp;O)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="313"/>
@@ -440,18 +427,18 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="322"/>
         <source>&amp;Copy to Clipboard</source>
-        <translation>Chép vào bộ điệm</translation>
+        <translation>Chép vào Bộ nhớ đệm (&amp;C)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="331"/>
         <location filename="../mainwindow.ui" line="334"/>
         <source>Next File</source>
-        <translation>Tập tin tiếp theo</translation>
+        <translation>Tập tin Tiếp theo</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="337"/>
         <source>PgDown</source>
-        <translation>Cuộn xuống</translation>
+        <translation>PgDown</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="346"/>
@@ -462,7 +449,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="352"/>
         <source>PgUp</source>
-        <translation>Cuộn lên</translation>
+        <translation>PgUp</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="364"/>
@@ -477,12 +464,12 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="379"/>
         <source>&amp;Fit</source>
-        <translation>Làm vừa, khớp</translation>
+        <translation>Vừa khớp (&amp;F)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="388"/>
         <source>&amp;Rotate Clockwise</source>
-        <translation>Xoay chiều đồng hồ</translation>
+        <translation>Xoay Theo chiều Đồng hồ (&amp;R)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="391"/>
@@ -492,7 +479,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="400"/>
         <source>Rotate &amp;Counterclockwise</source>
-        <translation>Xoay ngược đồng hồ</translation>
+        <translation>Xoay Ngược chiều Đồng hồ (&amp;C)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="403"/>
@@ -502,12 +489,12 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="408"/>
         <source>P&amp;references</source>
-        <translation>Tham chiếu</translation>
+        <translation>Tùy chọn (&amp;R)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="413"/>
         <source>&amp;Print</source>
-        <translation>In</translation>
+        <translation>In (&amp;P)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="416"/>
@@ -522,7 +509,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="428"/>
         <source>Home</source>
-        <translation>Gốc</translation>
+        <translation>Home</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="437"/>
@@ -532,12 +519,12 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="440"/>
         <source>End</source>
-        <translation>Kết thúc</translation>
+        <translation>End</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="449"/>
         <source>&amp;New Window</source>
-        <translation>Cửa sổ mới</translation>
+        <translation>Cửa sổ mới (&amp;N)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="452"/>
@@ -547,7 +534,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="457"/>
         <source>Flip &amp;Horizontally</source>
-        <translation>Lật ngang</translation>
+        <translation>Lật ngang (&amp;H)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="460"/>
@@ -562,7 +549,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="477"/>
         <source>F&amp;ull Screen</source>
-        <translation>Toàn màn hình</translation>
+        <translation>Toàn màn hình (&amp;U)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="480"/>
@@ -572,7 +559,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="485"/>
         <source>Flip &amp;Vertically</source>
-        <translation>Lật dọc</translation>
+        <translation>Lật dọc (&amp;V)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="488"/>
@@ -582,22 +569,22 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="497"/>
         <source>&amp;Paste from Clipboard</source>
-        <translation>Dán từ bộ điệm</translation>
+        <translation>Dán từ Bộ nhớ đệm (&amp;P)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="509"/>
         <source>&amp;Slide Show</source>
-        <translation>Trình chiếu</translation>
+        <translation>Trình chiếu (&amp;S)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="518"/>
         <source>&amp;Delete</source>
-        <translation>Xóa</translation>
+        <translation>Xóa (&amp;D)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="521"/>
         <source>Del</source>
-        <translation>Xóa</translation>
+        <translation>Del</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="529"/>
@@ -617,7 +604,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="546"/>
         <source>Open &amp;Directory</source>
-        <translation>Mở thư mục</translation>
+        <translation>Mở thư mục (&amp;D)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="549"/>
@@ -692,7 +679,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="647"/>
         <source>Draw incrementing numbers</source>
-        <translation>Vẽ số tăng</translation>
+        <translation>Vẽ các số tăng dần</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="655"/>
@@ -708,7 +695,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="669"/>
         <source>&amp;Main Toolbar</source>
-        <translation>Thanh công cụ chính</translation>
+        <translation>Thanh công cụ chính (&amp;M)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="672"/>
@@ -718,7 +705,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="680"/>
         <source>&amp;Annotations Toolbar</source>
-        <translation>Chú thích thanh công cụ</translation>
+        <translation>Thanh công cụ chú thích (&amp;A)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="691"/>
@@ -734,7 +721,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="705"/>
         <source>Copy Pa&amp;th</source>
-        <translation>Chép đường dẫn</translation>
+        <translation>Chép đường dẫn (&amp;T)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="708"/>
@@ -760,62 +747,62 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="739"/>
         <source>&amp;By File Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Tên Tập tin (&amp;B)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="742"/>
         <source>By File Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Tên Tập tin</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="750"/>
         <source>By &amp;Modification Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Thời gian Sửa đổi (&amp;M)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="753"/>
         <source>By Modification Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Thời gian Sửa đổi</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="761"/>
         <source>By C&amp;reation Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Thời gian Tạo (&amp;R)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="764"/>
         <source>By Creation Time</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Thời gian Tạo</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="772"/>
         <source>By File &amp;Size</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Kích thước Tập tin (&amp;S)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="775"/>
         <source>By File Size</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Kích thước Tập tin</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="783"/>
         <source>By File &amp;Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Kiểu Tập tin (&amp;T)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="786"/>
         <source>By File Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Theo Kiểu Tập tin</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="63"/>
         <source>&amp;File</source>
-        <translation>Tập tin</translation>
+        <translation>Tập tin (&amp;F)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="97"/>
         <source>&amp;Help</source>
-        <translation>Trợ giúp</translation>
+        <translation>Trợ giúp (&amp;H)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="104"/>
@@ -825,12 +812,12 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../mainwindow.ui" line="113"/>
         <source>&amp;View</source>
-        <translation>Xem</translation>
+        <translation>Xem (&amp;V)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="145"/>
         <source>&amp;Edit</source>
-        <translation>Chỉnh sửa</translation>
+        <translation>Chỉnh sửa (&amp;E)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="169"/>
@@ -871,12 +858,12 @@ trong chế độ chỉnh sửa.</translation>
         <translation>Số lượng tối đa những tập tin gần đây:</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="179"/>
+        <location filename="../preferencesdialog.ui" line="228"/>
         <source>Slide show interval (seconds):</source>
         <translation>Thời gian trình chiếu (giây):</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="193"/>
+        <location filename="../preferencesdialog.ui" line="242"/>
         <source>Show image outline by default</source>
         <translation>Hiện viền hình mặc định</translation>
     </message>
@@ -886,7 +873,7 @@ trong chế độ chỉnh sửa.</translation>
         <translation>Hiện chú thích thanh công cụ mặc định</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="200"/>
+        <location filename="../preferencesdialog.ui" line="249"/>
         <source>Fit images when navigating</source>
         <translation>Làm vừa hình khi điều hướng</translation>
     </message>
@@ -903,7 +890,7 @@ trong chế độ chỉnh sửa.</translation>
     <message>
         <location filename="../preferencesdialog.ui" line="86"/>
         <source>Use system Trash (and do not prompt)</source>
-        <translation>Dùng thùng rác (Trash) hệ thống (không hỏi lại)</translation>
+        <translation>Dùng Thùng rác hệ thống (và không hỏi lại)</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="94"/>
@@ -936,27 +923,69 @@ trong chế độ chỉnh sửa.</translation>
         <translation>Hình ảnh</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="207"/>
+        <location filename="../preferencesdialog.ui" line="179"/>
+        <location filename="../preferencesdialog.ui" line="190"/>
+        <source>May work only with images which have valid color spaces.
+Reload current image to see the effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="183"/>
+        <source>Color space:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="195"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="200"/>
+        <source>sRGB (supported by most monitors)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="205"/>
+        <source>Linear sRGB (linear gamma)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="210"/>
+        <source>Adobe RGB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="215"/>
+        <source>DisplayP3 (wide-gamut screens)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="220"/>
+        <source>ProPhotoRgb</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferencesdialog.ui" line="256"/>
         <source>Smooth images on zooming</source>
         <translation>Phóng to/thu nhỏ hình ảnh mượt mà</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="215"/>
+        <location filename="../preferencesdialog.ui" line="264"/>
         <source>Shortcuts</source>
         <translation>Lối tắt</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="234"/>
+        <location filename="../preferencesdialog.ui" line="283"/>
         <source>Action</source>
         <translation>Bắt đầu</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="239"/>
+        <location filename="../preferencesdialog.ui" line="288"/>
         <source>Shortcut</source>
         <translation>Lối tắt</translation>
     </message>
     <message>
-        <location filename="../preferencesdialog.ui" line="247"/>
+        <location filename="../preferencesdialog.ui" line="296"/>
         <source>Default</source>
         <translation>Mặc định</translation>
     </message>
@@ -969,7 +998,7 @@ trong chế độ chỉnh sửa.</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="989"/>
+        <location filename="../mainwindow.cpp" line="997"/>
         <source>Error</source>
         <translation>Lỗi</translation>
     </message>
